==> zio-aws-sagemaker_3-5.17.146.1-sources.jar: zio/aws/sagemaker/model/ModelBiasBaselineConfig.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.sagemaker.model.primitives.ProcessingJobName
import scala.jdk.CollectionConverters.*
final case class ModelBiasBaselineConfig(
    baseliningJobName: Option[ProcessingJobName] = None,
    constraintsResource: Option[
      zio.aws.sagemaker.model.MonitoringConstraintsResource
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.ModelBiasBaselineConfig = {
    import ModelBiasBaselineConfig.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.ModelBiasBaselineConfig
      .builder()
      .optionallyWith(
        baseliningJobName.map(value =>
          ProcessingJobName.unwrap(value): java.lang.String
        )
      )(_.baseliningJobName)
      .optionallyWith(constraintsResource.map(value => value.buildAwsValue()))(
        _.constraintsResource
      )
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.ModelBiasBaselineConfig.ReadOnly =
    zio.aws.sagemaker.model.ModelBiasBaselineConfig.wrap(buildAwsValue())
}
object ModelBiasBaselineConfig {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.ModelBiasBaselineConfig
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.ModelBiasBaselineConfig =
      zio.aws.sagemaker.model.ModelBiasBaselineConfig(
        baseliningJobName.map(value => value),
        constraintsResource.map(value => value.asEditable)
      )
    def baseliningJobName: Option[ProcessingJobName]
    def constraintsResource
        : Option[zio.aws.sagemaker.model.MonitoringConstraintsResource.ReadOnly]
    def getBaseliningJobName: ZIO[Any, AwsError, ProcessingJobName] =
      AwsError.unwrapOptionField("baseliningJobName", baseliningJobName)
    def getConstraintsResource: ZIO[
      Any,
      AwsError,
      zio.aws.sagemaker.model.MonitoringConstraintsResource.ReadOnly
    ] = AwsError.unwrapOptionField("constraintsResource", constraintsResource)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.ModelBiasBaselineConfig
  ) extends zio.aws.sagemaker.model.ModelBiasBaselineConfig.ReadOnly {
    override val baseliningJobName: Option[ProcessingJobName] = scala
      .Option(impl.baseliningJobName())
      .map(value => zio.aws.sagemaker.model.primitives.ProcessingJobName(value))
    override val constraintsResource: Option[
      zio.aws.sagemaker.model.MonitoringConstraintsResource.ReadOnly
    ] = scala
      .Option(impl.constraintsResource())
      .map(value =>
        zio.aws.sagemaker.model.MonitoringConstraintsResource.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.ModelBiasBaselineConfig
  ): zio.aws.sagemaker.model.ModelBiasBaselineConfig.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-sagemaker_3-7.21.15.8-sources.jar: zio/aws/sagemaker/model/ModelBiasBaselineConfig.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.sagemaker.model.primitives.ProcessingJobName
import scala.jdk.CollectionConverters.*
final case class ModelBiasBaselineConfig(
    baseliningJobName: Optional[ProcessingJobName] = Optional.Absent,
    constraintsResource: Optional[
      zio.aws.sagemaker.model.MonitoringConstraintsResource
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.ModelBiasBaselineConfig = {
    import ModelBiasBaselineConfig.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.ModelBiasBaselineConfig
      .builder()
      .optionallyWith(
        baseliningJobName.map(value =>
          ProcessingJobName.unwrap(value): java.lang.String
        )
      )(_.baseliningJobName)
      .optionallyWith(constraintsResource.map(value => value.buildAwsValue()))(
        _.constraintsResource
      )
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.ModelBiasBaselineConfig.ReadOnly =
    zio.aws.sagemaker.model.ModelBiasBaselineConfig.wrap(buildAwsValue())
}
object ModelBiasBaselineConfig {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.ModelBiasBaselineConfig
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.ModelBiasBaselineConfig =
      zio.aws.sagemaker.model.ModelBiasBaselineConfig(
        baseliningJobName.map(value => value),
        constraintsResource.map(value => value.asEditable)
      )
    def baseliningJobName: Optional[ProcessingJobName]
    def constraintsResource: Optional[
      zio.aws.sagemaker.model.MonitoringConstraintsResource.ReadOnly
    ]
    def getBaseliningJobName: ZIO[Any, AwsError, ProcessingJobName] =
      AwsError.unwrapOptionField("baseliningJobName", baseliningJobName)
    def getConstraintsResource: ZIO[
      Any,
      AwsError,
      zio.aws.sagemaker.model.MonitoringConstraintsResource.ReadOnly
    ] = AwsError.unwrapOptionField("constraintsResource", constraintsResource)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.ModelBiasBaselineConfig
  ) extends zio.aws.sagemaker.model.ModelBiasBaselineConfig.ReadOnly {
    override val baseliningJobName: Optional[ProcessingJobName] =
      zio.aws.core.internal
        .optionalFromNullable(impl.baseliningJobName())
        .map(value =>
          zio.aws.sagemaker.model.primitives.ProcessingJobName(value)
        )
    override val constraintsResource: Optional[
      zio.aws.sagemaker.model.MonitoringConstraintsResource.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.constraintsResource())
      .map(value =>
        zio.aws.sagemaker.model.MonitoringConstraintsResource.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.ModelBiasBaselineConfig
  ): zio.aws.sagemaker.model.ModelBiasBaselineConfig.ReadOnly = new Wrapper(
    impl
  )
}
